"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.getFirstFullTemplateId = exports.findById = exports.isPartial = void 0;

var _react = _interopRequireDefault(require("react"));

var _lodash = require("lodash");

var _q3UiRest = _interopRequireDefault(require("q3-ui-rest"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const isPartial = xs => !(xs !== null && xs !== void 0 && xs.name) || String(xs.name).startsWith('__');

exports.isPartial = isPartial;

const findById = (xs, id) => (0, _lodash.find)(xs, item => (item === null || item === void 0 ? void 0 : item.id) === id);

exports.findById = findById;

const getFirstFullTemplateId = xs => {
  var _find;

  return (_find = (0, _lodash.find)(xs, item => !isPartial(item))) === null || _find === void 0 ? void 0 : _find.id;
};

exports.getFirstFullTemplateId = getFirstFullTemplateId;

const useEmailTemplates = () => {
  const {
    emails = [],
    fetchingError = false,
    fetching = true,
    patch
  } = (0, _q3UiRest.default)({
    key: 'email',
    pluralized: 'emails',
    url: '/emails',
    runOnInit: true,
    location: {
      search: '?sort=name'
    }
  });

  const [active, setActive] = _react.default.useState();

  const current = findById(emails, active);

  const handleSave = mjml => patch(active)({
    mjml
  });

  _react.default.useEffect(() => {
    if ((0, _lodash.size)(emails) && !active) setActive(getFirstFullTemplateId(emails));
  }, [emails]);

  return {
    templates: emails,
    error: Boolean(fetchingError || !(0, _lodash.size)(emails)),
    ready: Boolean(!fetching && current) || fetchingError,
    disablePreview: isPartial(current),
    value: (current === null || current === void 0 ? void 0 : current.mjml) || '<mjml />',
    vars: (0, _lodash.get)(current, 'variables', {}),
    onSave: handleSave,
    setById: setActive,
    id: active
  };
};

var _default = useEmailTemplates;
exports.default = _default;